@@ -1,6 +1,6 @@
 #' Data grids
-#' 
-#' @description 
+#'
+#' @description
 #' Generate a data grid of user-specified values for use in the `newdata` argument of the `predictions()`, `comparisons()`, and `slopes()` functions. This is useful to define where in the predictor space we want to evaluate the quantities of interest. Ex: the predicted outcome or slope for a 37 year old college graduate.
 #'
 #' * `datagrid()` generates data frames with combinations of "typical" or user-supplied predictor values.
@@ -23,7 +23,7 @@
 #' @param FUN_other the function to be applied to other variable types.
 #' @details
 #' If `datagrid` is used in a `predictions()`, `comparisons()`, or `slopes()` call as the
-#' `newdata` argument, the model is automatically inserted in the `model` argument of `datagrid()` 
+#' `newdata` argument, the model is automatically inserted in the `model` argument of `datagrid()`
 #' call, and users do not need to specify either the `model` or `newdata` arguments.
 #'
 #' If users supply a model, the data used to fit that model is retrieved using
@@ -83,107 +83,16 @@ datagrid <- function(
     checkmate::assert_function(FUN_logical)
     checkmate::assert_function(FUN_numeric)
     checkmate::assert_function(FUN_other)
-
-    if (grid_type == "typical") {
-        args <- list( # cleaned for backward compatibility
-            model = model,
-            newdata = newdata,
-            FUN_character = FUN_character,
-            FUN_factor = FUN_factor,
-            FUN_logical = FUN_logical,
-            FUN_numeric = FUN_numeric,
-            FUN_integer = FUN_integer,
-            FUN_other = FUN_other)
-        args <- c(dots, args)
-        out <- do.call("typical", args)
-    } else {
+    
+    if (grid_type == "counterfactual") {
         args <- list(
             model = model,
             newdata = newdata)
         args <- c(dots, args)
-        out <- do.call("counterfactual", args)
+        out <- do.call("datagridcf", args)
+        return(out)
     }
-
-    # better to assume "standard" class as output
-    setDF(out)
-
-    attr(out, "variables_datagrid") <- names(dots)
-
-    return(out)
-}
-
-
-#' Counterfactual data grid
-#' @describeIn datagrid Counterfactual data grid
-#' @export
-#' 
-datagridcf <- function(
-    ...,
-    model = NULL,
-    newdata = NULL) {
-
-    dots <- list(...)
-
-    if (length(dots) == 0) {
-        insight::format_error("Users must specify variable values in the `datagridcf()` call.")
-    }
-
-    out <- datagrid(
-        ...,
-        model = model,
-        newdata = newdata,
-        grid_type = "counterfactual")
-
-    attr(out, "variables_datagrid") <- names(out)
-
-    return(out)
-        
-}
-
-
-#' @keywords internal
-counterfactual <- function(..., model = NULL, newdata = NULL) {
-
-    tmp <- prep_datagrid(..., model = model, newdata = newdata)
-    at <- tmp$at
-    dat <- tmp$newdata
-    variables_all <- tmp$all
-    variables_manual <- names(at)
-    variables_automatic <- tmp$automatic
-
-    # `at` -> `data.frame`
-    at <- lapply(at, unique)
-
-    fun <- data.table::CJ
-    args <- c(at, list(sorted = FALSE))
-    at <- do.call("fun", args)
-
-    rowid <- data.frame(rowidcf = seq_len(nrow(dat)))
-    if (length(variables_automatic) > 0) {
-        idx <- intersect(variables_automatic, colnames(dat))
-        dat_automatic <- dat[, ..idx, drop = FALSE]
-        dat_automatic <- cbind(rowid, dat_automatic)
-        out <- merge(dat_automatic, at, all = TRUE)
-    }  else {
-        out <- merge(rowid, at, all = TRUE)
-    }
-
-    return(out)
-}
-
-
-typical <- function(
-    ...,
-    model = NULL,
-    newdata = NULL,
-    FUN_character = get_mode,
-    # need to be explicit for numeric variables transfered to factor in model formula
-    FUN_factor = get_mode,
-    FUN_logical = get_mode,
-    FUN_numeric = function(x) mean(x, na.rm = TRUE),
-    FUN_integer = function(x) round(mean(x, na.rm = TRUE)),
-    FUN_other = function(x) mean(x, na.rm = TRUE)) {
-
+    
     tmp <- prep_datagrid(..., model = model, newdata = newdata)
 
     at <- tmp$at
@@ -208,7 +117,7 @@ typical <- function(
         # na.omit destroys attributes, and we need the "factor" attribute
         # created by insight::get_data
         for (n in names(dat_automatic)) {
-            if (get_variable_class(dat, n, "factor") || n %in% tmp[["cluster"]]) {
+            if (get_variable_class(dat, n, c("factor", "strata", "cluster")) || n %in% tmp[["cluster"]]) {
                 out[[n]] <- FUN_factor(dat_automatic[[n]])
             } else if (get_variable_class(dat, n, "logical")) {
                 out[[n]] <- FUN_logical(dat_automatic[[n]])
@@ -254,15 +163,79 @@ typical <- function(
         attr(out, "marginaleffects_variable_class") <- attr(dat, "marginaleffects_variable_class")
     }
 
+    # better to assume "standard" class as output
+    data.table::setDF(out)
+
+    attr(out, "variables_datagrid") <- names(dots)
+
     return(out)
 }
 
 
+#' Counterfactual data grid
+#' @describeIn datagrid Counterfactual data grid
+#' @export
+#'
+datagridcf <- function(
+    ...,
+    model = NULL,
+    newdata = NULL) {
+
+    dots <- list(...)
+
+    if (length(dots) == 0) {
+        insight::format_error("Users must specify variable values in the `datagridcf()` call.")
+    }
+
+    tmp <- prep_datagrid(..., model = model, newdata = newdata)
+    at <- tmp$at
+    dat <- tmp$newdata
+    variables_all <- tmp$all
+    variables_manual <- names(at)
+    variables_automatic <- tmp$automatic
+
+    # `at` -> `data.frame`
+    at <- lapply(at, unique)
+
+    fun <- data.table::CJ
+    args <- c(at, list(sorted = FALSE))
+    at <- do.call("fun", args)
+
+    rowid <- data.frame(rowidcf = seq_len(nrow(dat)))
+    if (length(variables_automatic) > 0) {
+        idx <- intersect(variables_automatic, colnames(dat))
+        dat_automatic <- dat[, ..idx, drop = FALSE]
+        dat_automatic[, rowidcf := rowid$rowidcf]
+        setcolorder(dat_automatic, c("rowidcf", setdiff(names(dat_automatic), "rowidcf")))
+        # cross-join 2 data.tables, faster than merging two dataframes
+        out <- cjdt(list(dat_automatic, at))
+    }  else {
+        out <- merge(rowid, at, all = TRUE)
+    }
+
+    data.table::setDF(out)
+
+    attr(out, "variables_datagrid") <- names(out)
+
+    return(out)
+
+}
+
+
 prep_datagrid <- function(..., model = NULL, newdata = NULL) {
 
     checkmate::assert_data_frame(newdata, null.ok = TRUE)
 
     at <- list(...)
+    
+    # e.g., mlogit vignette we plot by group, but group is of length 0 because
+    # we don't know how many groups there are until we make the first
+    # prediction.
+    for (i in seq_along(at)) {
+        if (length(at[[i]]) == 0) {
+            at[[i]] <- NULL
+        }
+    }
 
     # if (!is.null(model) & !is.null(newdata)) {
     #     msg <- "One of the `model` or `newdata` arguments must be `NULL`."
@@ -291,7 +264,21 @@ prep_datagrid <- function(..., model = NULL, newdata = NULL) {
 
     # fill in missing data after sanity checks
     if (is.null(newdata)) {
-        newdata <- get_modeldata(model)
+        newdata <- get_modeldata(model, additional_variables = FALSE)
+    }
+    
+    attr_variable_classes <- attr(newdata, "marginaleffects_variable_class")
+
+    # subset columns, otherwise it can be ultra expensive to compute summaries for every variable
+    if (!is.null(model)) {
+        variables_sub <- c(
+            hush(insight::find_variables(model, flatten = TRUE)),
+            hush(unlist(insight::find_weights(model), use.names = FALSE))) # glmmTMB needs weights column for predictions
+        variables_sub <- c(variables_sub, variables_manual)
+        variables_sub <- intersect(colnames(newdata), variables_sub)
+        if (length(variables_sub) > 0) {
+            newdata <- subset(newdata, select = variables_sub)
+        }
     }
 
     # check `at` names
@@ -310,7 +297,6 @@ prep_datagrid <- function(..., model = NULL, newdata = NULL) {
         newdata <- newdata[, !idx, drop = FALSE]
     }
 
-
     # check `at` elements and convert them to factor as needed
     for (n in names(at)) {
         # functions first otherwise we try to coerce functions to character
@@ -339,7 +325,7 @@ prep_datagrid <- function(..., model = NULL, newdata = NULL) {
             }
         }
     }
-
+    
     # cluster identifiers will eventually be treated as factors
     if (!is.null(model)) {
         v <- insight::find_variables(model)
@@ -349,7 +335,9 @@ prep_datagrid <- function(..., model = NULL, newdata = NULL) {
         variables_cluster <- NULL
     }
 
-    setDT(newdata)
+    data.table::setDT(newdata)
+    
+    attr(newdata, "marginaleffects_variable_class") <- attr_variable_classes
 
     out <- list("newdata" = newdata,
                 "at" = at,
@@ -358,6 +346,4 @@ prep_datagrid <- function(..., model = NULL, newdata = NULL) {
                 "automatic" = variables_automatic,
                 "cluster" = variables_cluster)
     return(out)
-}
-
-
+}
\ No newline at end of file
