@@ -38,8 +38,8 @@ plot_comparisons <- function(model,
                              type = "response",
                              vcov = NULL,
                              conf_level = 0.95,
-                             transform_pre = "difference",
-                             transform_post = NULL,
+                             comparison = "difference",
+                             transform = NULL,
                              rug = FALSE,
                              gray = FALSE,
                              draw = TRUE,
@@ -83,8 +83,8 @@ plot_comparisons <- function(model,
             by = FALSE,
             wts = NULL,
             variables = variables,
-            transform_pre = transform_pre,
-            transform_post = transform_post,
+            comparison = comparison,
+            transform = transform,
             cross = FALSE,
             modeldata = modeldata,
             ...)
@@ -101,8 +101,8 @@ plot_comparisons <- function(model,
             conf_level = conf_level,
             variables = variables,
             wts = NULL,
-            transform_pre = transform_pre,
-            transform_post = transform_post,
+            comparison = comparison,
+            transform = transform,
             cross = FALSE,
             modeldata = modeldata,
             ...)
