@@ -46,7 +46,7 @@ plot_predictions <- function(model,
                              type = NULL,
                              vcov = NULL,
                              conf_level = 0.95,
-                             transform_post = NULL,
+                             transform = NULL,
                              points = 0,
                              rug = FALSE,
                              gray = FALSE,
@@ -85,7 +85,7 @@ plot_predictions <- function(model,
             type = type,
             vcov = vcov,
             conf_level = conf_level,
-            transform_post = transform_post,
+            transform = transform,
             modeldata = modeldata,
             ...)
     }
@@ -101,7 +101,7 @@ plot_predictions <- function(model,
             vcov = vcov,
             conf_level = conf_level,
             wts = NULL,
-            transform_post = transform_post,
+            transform = transform,
             modeldata = modeldata,
             ...)
         v_x <- by[[1]]
