@@ -67,7 +67,7 @@
 #' + numeric: vector of length equal to the number of rows in the original data or in `newdata` (if supplied).
 #' @param hypothesis specify a hypothesis test or custom contrast using a numeric value, vector, or matrix, a string, or a string formula.
 #' + Numeric:
-#'   - Single value: the null hypothesis used in the computation of Z and p (before applying `transform_post`).
+#'   - Single value: the null hypothesis used in the computation of Z and p (before applying `transform`).
 #'   - Vector: Weights to compute a linear combination of (custom contrast between) estimates. Length equal to the number of rows generated by the same function call, but without the `hypothesis` argument.
 #'   - Matrix: Each column is a vector of weights, as describe above, used to compute a distinct linear combination of (contrast between) estimates. The column names of the matrix are used as labels in the output.
 #' + String formula to specify linear or non-linear hypothesis tests. If the `term` column uniquely identifies rows, terms can be used in the formula. Otherwise, use `b1`, `b2`, etc. to identify the position of each parameter. Examples:
@@ -80,6 +80,7 @@
 #'   - "sequential": difference between an estimate and the estimate in the next row.
 #'   - "revpairwise", "revreference", "revsequential": inverse of the corresponding hypotheses, as described above.
 #' + See the Examples section below and the vignette: https://vincentarelbundock.github.io/marginaleffects/articles/hypothesis.html
+#' @param p_adjust Adjust p-values for multiple comparisons: "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", or "fdr". See [stats::p.adjust]
 #' @param df Degrees of freedom used to compute p values and confidence intervals. A single numeric value between 1 and `Inf`. When `df` is `Inf`, the normal distribution is used. When `df` is finite, the `t` distribution is used. See [insight::get_df] for a convenient function to extract degrees of freedom. Ex: `slopes(model, df = insight::get_df(model))`
 #' @param eps NULL or numeric value which determines the step size to use when
 #' calculating numerical derivatives: (f(x+eps)-f(x))/eps. When `eps` is
@@ -105,6 +106,7 @@
 #' @template deltamethod
 #' @template model_specific_arguments
 #' @template bayesian
+#' @template equivalence
 #'
 #' @return A `data.frame` with one row per observation (per term/group) and several columns:
 #' * `rowid`: row number of the `newdata` data frame
@@ -197,6 +199,8 @@ slopes <- function(model,
                    slope = "dydx",
                    wts = NULL,
                    hypothesis = NULL,
+                   equivalence = NULL,
+                   p_adjust = NULL,
                    df = Inf,
                    eps = NULL,
                    ...) {
@@ -260,10 +264,12 @@ slopes <- function(model,
         type = type,
         wts = wts,
         hypothesis = hypothesis,
+        equivalence = equivalence,
         df = df,
+        p_adjust = p_adjust,
         by = by,
         eps = eps,
-        transform_pre = slope,
+        comparison = slope,
         cross = FALSE,
         # secret arguments
         internal_call = TRUE,
@@ -272,7 +278,7 @@ slopes <- function(model,
     data.table::setDT(out)
 
     # clean columns
-    stubcols <- c("rowid", "type", "group", "term", "contrast", "hypothesis", "dydx", "estimate", "std.error", "statistic", "p.value", "conf.low", "conf.high",
+    stubcols <- c("rowid", "group", "term", "contrast", "hypothesis", "dydx", "estimate", "std.error", "statistic", "p.value", "conf.low", "conf.high",
                   sort(grep("^predicted", colnames(newdata), value = TRUE)))
     cols <- intersect(stubcols, colnames(out))
     cols <- unique(c(cols, colnames(out)))
@@ -339,6 +345,8 @@ avg_slopes <- function(model,
                        slope = "dydx",
                        wts = NULL,
                        hypothesis = NULL,
+                       equivalence = NULL,
+                       p_adjust = NULL,
                        df = Inf,
                        eps = NULL,
                        ...) {
@@ -372,6 +380,8 @@ avg_slopes <- function(model,
         slope = slope,
         wts = wts,
         hypothesis = hypothesis,
+        equivalence = equivalence,
+        p_adjust = p_adjust,
         df = df,
         eps = eps,
         ...)
