@@ -1,7 +1,7 @@
 source("helpers.R")
 using("marginaleffects")
 
-exit_if_not(requiet("emmeans"))
+requiet("emmeans")
 
 dat <- mtcars
 dat$carb <- factor(dat$carb)
@@ -9,6 +9,8 @@ dat$cyl <- factor(dat$cyl)
 mod <- lm(mpg ~ carb + cyl, dat)
 
 
+
+
 # informative errors and warnings
 tmp <- lm(mpg ~ drat + wt, data = mtcars)
 expect_error(slopes(tmp, hypothesis = "drat = wt"), pattern = "newdata")
@@ -125,7 +127,7 @@ expect_equivalent(p3$term, c("Contrast A", "Contrast B"))
 # marginalmeans: hypothesis complex
 lc <- c(-2, 1, 1, 0, -1, 1)
 em <- emmeans(mod, "carb") 
-em <- contrast(em, method = data.frame(custom_contrast = lc))
+em <- emmeans::contrast(em, method = data.frame(custom_contrast = lc))
 em <- data.frame(em)
 mm <- marginal_means(mod, variables = "carb", hypothesis = lc)
 expect_equivalent(mm$estimate, em$estimate)
@@ -230,23 +232,38 @@ dm <- hypotheses(mod, hypothesis = H)
 expect_equivalent(dm$term, c("H1", "H2"))
 
 
+# Informative error on row mismatch
+mod <- lm(mpg ~ hp + drat, data = mtcars)
+expect_error(
+    predictions(mod, newdata = "mean", hypothesis = "b1=b2"),
+    pattern = "hypothesis testing")
+
+# Issue #661: remove redundant labels in pairwise comparisons
+if (!requiet("tinysnapshot")) exit_file("tinysnapshot")
+using("tinysnapshot")
+set.seed(123)
+dat <- transform(iris, dummy = as.factor(rbinom(nrow(iris), 1, prob = c(0.4, 0.6))))
+m <- lm(Sepal.Width ~ Sepal.Length * Species + dummy, data = dat)
+mfx <- slopes(m, variables = "Sepal.Length", by = c("Species", "dummy"), hypothesis = "pairwise")
+expect_true("setosa, 0 - setosa, 1" %in% mfx$term)
+
 
 # # Issue #568
-# # TODO: p-value computed before transform_post; null on the pre-transform scale
+# # TODO: p-value computed before transform; null on the pre-transform scale
 # mod <- glm(vs ~ hp, data = mtcars, family = binomial)
 
 # comparisons(mod,
 #     newdata = "mean",
-#     transform_pre = "ratio")
+#     comparison = "ratio")
 
 # comparisons(mod,
 #     newdata = "mean",
-#     transform_pre = "ratio",
+#     comparison = "ratio",
 #     hypothesis = 0)
 
 # comparisons(mod,
 #     newdata = "mean",
-#     transform_pre = "ratio",
+#     comparison = "ratio",
 #     hypothesis = 1)
 
 # marginaleffects
@@ -255,4 +272,7 @@ expect_equivalent(dm$term, c("H1", "H2"))
 
 # predictions(mod, newdata = "mean", hypothesis = .75)
 
-# slopes(mod, newdata = "mean", hypothesis = .75)
\ No newline at end of file
+# slopes(mod, newdata = "mean", hypothesis = .75)
+
+
+rm(list = ls())
\ No newline at end of file
