@@ -1,6 +1,5 @@
 source("helpers.R")
-exit_if_not(packageVersion("base") >= "4.1.0")
-exit_if_not(EXPENSIVE)
+if (!EXPENSIVE) exit_file("EXPENSIVE")
 
 set.seed(1024)
 R <- 100
@@ -87,4 +86,7 @@ expect_error(inferences(comparisons(mod, wts = "w"), method = "fwb"), pattern =
 
 # marginal_means not supported
 mod <- lm(Petal.Length ~ Sepal.Length * Sepal.Width * Species, data = iris)
-expect_error(inferences(marginal_means(mod), method = "fwb"), pattern = "not supported")
\ No newline at end of file
+expect_error(inferences(marginal_means(mod), method = "fwb"), pattern = "not supported")
+
+
+rm(list = ls())
\ No newline at end of file
